@@ -14,6 +14,7 @@ EXPRESSION_TRIGGER = 'expression'
 
 
 class Trigger(Base):
+    QUERY_PARAM_VALIDATE_FLAG = 'validate'
 
     def __init__(
             self,
@@ -149,21 +150,21 @@ class Trigger(Base):
             api_response = TriggerManager(self._client).fetch_by_id(trigger_id)
 
         if trigger_id and api_response:
-            res = self._client.put('trigger/{id}'.format(id=trigger_id), json=data)
+            res = self._client.put('trigger/{}?{}'.format(trigger_id, self.QUERY_PARAM_VALIDATE_FLAG, json=data))
         else:
-            res = self._client.put('trigger', json=data)
-        
+            res = self._client.put('trigger?{}'.format(self.QUERY_PARAM_VALIDATE_FLAG, json=data))
+
         if 'id' not in res:
             raise ResponseStructureError('id not in response', res)
-        
+
         self._id = res['id']
-        return self._id
+        return res
 
     def save(self):
         """
         Save trigger
 
-        :return: trigger_id
+        :return: response object
         """
         if self._id:
             return self.update()
@@ -171,8 +172,7 @@ class Trigger(Base):
 
         if trigger:
             self._id = trigger.id
-            self.update()
-            return trigger.id
+            return self.update()
 
         return self._send_request()
 
@@ -180,7 +180,7 @@ class Trigger(Base):
         """
         Update trigger
 
-        :return: trigger id
+        :return: response object
         """
         return self._send_request(self._id)
 
